X3m.System.AggregateRegistry (X3m System v0.9.0)

Copy Markdown View Source

Keeps track of registered aggregate pids.

Summary

Functions

Returns a specification to start this module under a supervisor.

Looks up the process pid for id stored in server.

Returns true if key is already registered in server, false otherwise.

Callback implementation for GenServer.init/1.

Ensures there is a pid associated with key in server.

Starts process registry

Functions

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

get(server, key)

Looks up the process pid for id stored in server.

Returns {:ok, pid} if the one exists, :error otherwise.

has_key?(server, key)

Returns true if key is already registered in server, false otherwise.

init(name)

Callback implementation for GenServer.init/1.

name(aggregate_mod)

register(server, key, pid)

Ensures there is a pid associated with key in server.

Returns :ok once when process is successfully registered

start_link(name)

Starts process registry