Keeps track of registered aggregate pids.
Summary
Functions
Returns a specification to start this module under a supervisor.
Looks up the process pid for id stored in server.
Returns true if key is already registered in server, false otherwise.
Callback implementation for GenServer.init/1.
Ensures there is a pid associated with key in server.
Starts process registry
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
Looks up the process pid for id stored in server.
Returns {:ok, pid} if the one exists, :error otherwise.
Returns true if key is already registered in server, false otherwise.
Callback implementation for GenServer.init/1.
Ensures there is a pid associated with key in server.
Returns :ok once when process is successfully registered
Starts process registry